searchData={"content_type":"text/markdown","items":[{"doc":"Custom implementations for number formatting functions.\nReplaces functionality from the 'number' dependency.","ref":"NumberF.CustomFormatter.html","title":"NumberF.CustomFormatter","type":"module"},{"doc":"Formats a number as currency with specified unit and precision.","ref":"NumberF.CustomFormatter.html#number_to_currency/2","title":"NumberF.CustomFormatter.number_to_currency/2","type":"function"},{"doc":"iex> NumberF.CustomFormatter.number_to_currency(1234.56, unit: \"USD\", precision: 2)\n    \"USD 1,234.56\"\n\n    iex> NumberF.CustomFormatter.number_to_currency(\"1234.56\", unit: \"USD\", precision: 2)\n    \"USD 1,234.56\"","ref":"NumberF.CustomFormatter.html#number_to_currency/2-examples","title":"Examples - NumberF.CustomFormatter.number_to_currency/2","type":"function"},{"doc":"Formats a number with delimiters for thousands and decimal separator.","ref":"NumberF.CustomFormatter.html#number_to_delimited/2","title":"NumberF.CustomFormatter.number_to_delimited/2","type":"function"},{"doc":"iex> NumberF.CustomFormatter.number_to_delimited(1234567.89, delimiter: \",\", separator: \".\", precision: 2)\n    \"1,234,567.89\"\n\n    iex> NumberF.CustomFormatter.number_to_delimited(\"1234567.89\", delimiter: \",\", separator: \".\", precision: 2)\n    \"1,234,567.89\"","ref":"NumberF.CustomFormatter.html#number_to_delimited/2-examples","title":"Examples - NumberF.CustomFormatter.number_to_delimited/2","type":"function"},{"doc":"Converts a value to a Decimal.","ref":"NumberF.CustomFormatter.html#to_decimal/1","title":"NumberF.CustomFormatter.to_decimal/1","type":"function"},{"doc":"iex> NumberF.CustomFormatter.to_decimal(\"123.45\")\n    #Decimal<123.45>\n\n    iex> NumberF.CustomFormatter.to_decimal(123)\n    #Decimal<123>","ref":"NumberF.CustomFormatter.html#to_decimal/1-examples","title":"Examples - NumberF.CustomFormatter.to_decimal/1","type":"function"},{"doc":"Converts a value to a float.","ref":"NumberF.CustomFormatter.html#to_float/1","title":"NumberF.CustomFormatter.to_float/1","type":"function"},{"doc":"iex> NumberF.CustomFormatter.to_float(\"123.45\")\n    123.45\n\n    iex> NumberF.CustomFormatter.to_float(123)\n    123.0","ref":"NumberF.CustomFormatter.html#to_float/1-examples","title":"Examples - NumberF.CustomFormatter.to_float/1","type":"function"},{"doc":"# NumberF\n\nA comprehensive utility module for performing various number-related operations in Elixir.","ref":"NumberF.html","title":"NumberF","type":"module"},{"doc":"","ref":"NumberF.html#module-features","title":"Features - NumberF","type":"module"},{"doc":"Add `number_f` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n[\n  {:number_f, \"~> 0.1.3\"}\n]\nend\n```","ref":"NumberF.html#module-installation","title":"Installation - NumberF","type":"module"},{"doc":"- Format numbers as currency values with custom units\n- Create comma-separated number formats\n- Custom number delimiter formatting","ref":"NumberF.html#module-formatting","title":"Formatting - NumberF","type":"module"},{"doc":"- Convert numbers to words representation\n- Convert between various numeric types (int, float, decimal)\n- Convert strings to boolean values","ref":"NumberF.html#module-conversion","title":"Conversion - NumberF","type":"module"},{"doc":"- Generate random strings with customizable properties\n- Create default passwords with predefined patterns","ref":"NumberF.html#module-generation","title":"Generation - NumberF","type":"module"},{"doc":"- Convert memory sizes to human-readable formats\n- Sum decimal values, including in nested lists","ref":"NumberF.html#module-utilities","title":"Utilities - NumberF","type":"module"},{"doc":"```elixir\n# Currency formatting\nNumberF.currency(1234.567)                    # => \"ZMW 1,234.57\"\nNumberF.currency(1234.567, \"USD\", 2)          # => \"USD 1,234.57\"\nNumberF.comma_separated(1234567.89)           # => \"1,234,567.89\"\n\n# Numbers to words\nNumberF.to_words(20.0)                        # => \"Twenty Kwacha and zero Ngwee\"\nNumberF.to_words(42.75, \"Dollars\", \"Cents\")   # => \"Forty Two Dollars And Seventy Five Cents\"\n\n# Random generation\nNumberF.randomizer(10)                        # => \"a1B2c3D4e5\"\nNumberF.default_password()                    # => \"Dev@2308\"\n\n# Memory size humanization\nNumberF.memory_size_cal(1048576)              # => \"1.0 MB\"\n\n# Type conversions\nNumberF.to_int(\"123\")                         # => 123\nNumberF.to_float(\"123.45\")                    # => 123.45\nNumberF.to_decimal(\"123.45\")                  # => #Decimal<123.45>\nNumberF.to_boolean(\"yes\")                     # => true\n\n# Custom formatting\nNumberF.number_to_delimited(1234567.89, delimiter: \".\", separator: \",\") # => \"1.234.567,89\"\n```","ref":"NumberF.html#module-examples","title":"Examples - NumberF","type":"module"},{"doc":"Formats large numbers as K, M, B (e.g., 1.2K, 3.4M).","ref":"NumberF.html#abbreviate_number/2","title":"NumberF.abbreviate_number/2","type":"function"},{"doc":"- `number`: The number to abbreviate\n  - `precision`: Number of decimal places (default: 1)","ref":"NumberF.html#abbreviate_number/2-parameters","title":"Parameters - NumberF.abbreviate_number/2","type":"function"},{"doc":"iex> NumberF.abbreviate_number(1234)\n    \"1.2K\"\n\n    iex> NumberF.abbreviate_number(1234567)\n    \"1.2M\"\n\n    iex> NumberF.abbreviate_number(1234567890)\n    \"1.2B\"","ref":"NumberF.html#abbreviate_number/2-examples","title":"Examples - NumberF.abbreviate_number/2","type":"function"},{"doc":"Calculates age based on birth date.","ref":"NumberF.html#calculate_age/1","title":"NumberF.calculate_age/1","type":"function"},{"doc":"- `birth_date`: Birth date as Date struct","ref":"NumberF.html#calculate_age/1-parameters","title":"Parameters - NumberF.calculate_age/1","type":"function"},{"doc":"iex> birth_date = ~D[1990-01-15]\n    iex> age = NumberF.calculate_age(birth_date)\n    # Returns the current age based on today's date","ref":"NumberF.html#calculate_age/1-examples","title":"Examples - NumberF.calculate_age/1","type":"function"},{"doc":"Calculates Equated Monthly Installment (EMI) for loans.","ref":"NumberF.html#calculate_emi/3","title":"NumberF.calculate_emi/3","type":"function"},{"doc":"- `principal`: The loan amount\n  - `rate`: The annual interest rate as a decimal (e.g., 0.05 for 5%)\n  - `term_months`: The loan term in months","ref":"NumberF.html#calculate_emi/3-parameters","title":"Parameters - NumberF.calculate_emi/3","type":"function"},{"doc":"iex> NumberF.calculate_emi(100000, 0.10, 12)\n    8791.59","ref":"NumberF.html#calculate_emi/3-examples","title":"Examples - NumberF.calculate_emi/3","type":"function"},{"doc":"Formats a number into comma-separated format with the specified precision.","ref":"NumberF.html#comma_separated/2","title":"NumberF.comma_separated/2","type":"function"},{"doc":"- `number`: The number to format\n  - `precision`: Decimal places (default: 2)","ref":"NumberF.html#comma_separated/2-parameters","title":"Parameters - NumberF.comma_separated/2","type":"function"},{"doc":"iex> NumberF.comma_separated(1234567.89)\n    \"1,234,567.89\"\n\n    iex> NumberF.comma_separated(1234567.89, 0)\n    \"1,234,568\"\n\n    iex> NumberF.comma_separated(nil, 2)\n    nil","ref":"NumberF.html#comma_separated/2-examples","title":"Examples - NumberF.comma_separated/2","type":"function"},{"doc":"Calculates compound interest with optional compounding frequency.","ref":"NumberF.html#compound_interest/4","title":"NumberF.compound_interest/4","type":"function"},{"doc":"- `principal`: The principal amount\n  - `rate`: The annual interest rate as a decimal (e.g., 0.05 for 5%)\n  - `time`: The time period in years\n  - `frequency`: Number of times interest is compounded per year (default: 1)","ref":"NumberF.html#compound_interest/4-parameters","title":"Parameters - NumberF.compound_interest/4","type":"function"},{"doc":"iex> NumberF.compound_interest(1000, 0.05, 2)\n    102.5\n\n    iex> NumberF.compound_interest(1000, 0.05, 2, 12)\n    104.94","ref":"NumberF.html#compound_interest/4-examples","title":"Examples - NumberF.compound_interest/4","type":"function"},{"doc":"Converts an amount between currencies based on exchange rates.","ref":"NumberF.html#convert_currency/3","title":"NumberF.convert_currency/3","type":"function"},{"doc":"- `amount`: The amount to convert\n  - `from_rate`: The exchange rate of the source currency\n  - `to_rate`: The exchange rate of the target currency","ref":"NumberF.html#convert_currency/3-parameters","title":"Parameters - NumberF.convert_currency/3","type":"function"},{"doc":"iex> NumberF.convert_currency(100, 1, 1.1)\n    110.0","ref":"NumberF.html#convert_currency/3-examples","title":"Examples - NumberF.convert_currency/3","type":"function"},{"doc":"Formats a number into currency with the specified unit and precision.","ref":"NumberF.html#currency/3","title":"NumberF.currency/3","type":"function"},{"doc":"- `number`: The number to format\n  - `unit`: The currency unit (default: \"ZMW\")\n  - `precision`: Decimal places (default: 2)","ref":"NumberF.html#currency/3-parameters","title":"Parameters - NumberF.currency/3","type":"function"},{"doc":"iex> NumberF.currency(1234.567)\n    \"ZMW 1,234.57\"\n\n    iex> NumberF.currency(1234.567, \"USD\", 2)\n    \"USD 1,234.57\"\n\n    iex> NumberF.currency(nil, \"USD\", 2)\n    nil","ref":"NumberF.html#currency/3-examples","title":"Examples - NumberF.currency/3","type":"function"},{"doc":"Generates a default password with pre-defined complexity.\nThe pattern is: capitalized 3-letter string + @ + 4 random digits.","ref":"NumberF.html#default_password/0","title":"NumberF.default_password/0","type":"function"},{"doc":"iex> NumberF.default_password()\n    \"Dev@2308\" # Example output, actual value will vary","ref":"NumberF.html#default_password/0-examples","title":"Examples - NumberF.default_password/0","type":"function"},{"doc":"Formats phone numbers based on country code.","ref":"NumberF.html#format_phone/2","title":"NumberF.format_phone/2","type":"function"},{"doc":"- `number`: The phone number as a string\n  - `country_code`: The country code (default: \"ZM\" for Zambia)","ref":"NumberF.html#format_phone/2-parameters","title":"Parameters - NumberF.format_phone/2","type":"function"},{"doc":"iex> NumberF.format_phone(\"260977123456\", \"ZM\")\n    \"+260 97 712 3456\"\n\n    iex> NumberF.format_phone(\"14155552671\", \"US\")\n    \"+1 (415) 555-2671\"","ref":"NumberF.html#format_phone/2-examples","title":"Examples - NumberF.format_phone/2","type":"function"},{"doc":"Converts Roman numerals to Arabic numbers.","ref":"NumberF.html#from_roman/1","title":"NumberF.from_roman/1","type":"function"},{"doc":"- `roman`: The Roman numeral string","ref":"NumberF.html#from_roman/1-parameters","title":"Parameters - NumberF.from_roman/1","type":"function"},{"doc":"iex> NumberF.from_roman(\"IV\")\n    4\n\n    iex> NumberF.from_roman(\"XLII\")\n    42\n\n    iex> NumberF.from_roman(\"MCMXCIX\")\n    1999","ref":"NumberF.html#from_roman/1-examples","title":"Examples - NumberF.from_roman/1","type":"function"},{"doc":"Checks if a number is within a specified range (inclusive).","ref":"NumberF.html#in_range?/3","title":"NumberF.in_range?/3","type":"function"},{"doc":"- `value`: The number to check\n  - `min`: The minimum value of the range\n  - `max`: The maximum value of the range","ref":"NumberF.html#in_range?/3-parameters","title":"Parameters - NumberF.in_range?/3","type":"function"},{"doc":"iex> NumberF.in_range?(5, 1, 10)\n    true\n\n    iex> NumberF.in_range?(15, 1, 10)\n    false","ref":"NumberF.html#in_range?/3-examples","title":"Examples - NumberF.in_range?/3","type":"function"},{"doc":"Validates credit card numbers using the Luhn algorithm.","ref":"NumberF.html#is_valid_credit_card?/2","title":"NumberF.is_valid_credit_card?/2","type":"function"},{"doc":"- `number`: The credit card number as a string\n  - `type`: Card type to validate against (default: :any)\n    - Options: :any, :visa, :mastercard, :amex, :discover","ref":"NumberF.html#is_valid_credit_card?/2-parameters","title":"Parameters - NumberF.is_valid_credit_card?/2","type":"function"},{"doc":"iex> NumberF.is_valid_credit_card?(\"4111111111111111\")\n    true\n\n    iex> NumberF.is_valid_credit_card?(\"4111111111111112\")\n    false","ref":"NumberF.html#is_valid_credit_card?/2-examples","title":"Examples - NumberF.is_valid_credit_card?/2","type":"function"},{"doc":"Checks if a string is a valid integer.","ref":"NumberF.html#is_valid_integer?/1","title":"NumberF.is_valid_integer?/1","type":"function"},{"doc":"- `str`: The string to check","ref":"NumberF.html#is_valid_integer?/1-parameters","title":"Parameters - NumberF.is_valid_integer?/1","type":"function"},{"doc":"iex> NumberF.is_valid_integer?(\"123\")\n    true\n\n    iex> NumberF.is_valid_integer?(\"123.45\")\n    false","ref":"NumberF.html#is_valid_integer?/1-examples","title":"Examples - NumberF.is_valid_integer?/1","type":"function"},{"doc":"Checks if a string is a valid number format.","ref":"NumberF.html#is_valid_number?/1","title":"NumberF.is_valid_number?/1","type":"function"},{"doc":"- `str`: The string to check","ref":"NumberF.html#is_valid_number?/1-parameters","title":"Parameters - NumberF.is_valid_number?/1","type":"function"},{"doc":"iex> NumberF.is_valid_number?(\"123\")\n    true\n\n    iex> NumberF.is_valid_number?(\"123.45\")\n    true\n\n    iex> NumberF.is_valid_number?(\"abc\")\n    false","ref":"NumberF.html#is_valid_number?/1-examples","title":"Examples - NumberF.is_valid_number?/1","type":"function"},{"doc":"Calculates the arithmetic mean of a list of numbers.","ref":"NumberF.html#mean/1","title":"NumberF.mean/1","type":"function"},{"doc":"- `numbers`: A list of numbers","ref":"NumberF.html#mean/1-parameters","title":"Parameters - NumberF.mean/1","type":"function"},{"doc":"iex> NumberF.mean([1, 2, 3, 4, 5])\n    3.0","ref":"NumberF.html#mean/1-examples","title":"Examples - NumberF.mean/1","type":"function"},{"doc":"Finds the median value from a list of numbers.","ref":"NumberF.html#median/1","title":"NumberF.median/1","type":"function"},{"doc":"- `numbers`: A list of numbers","ref":"NumberF.html#median/1-parameters","title":"Parameters - NumberF.median/1","type":"function"},{"doc":"iex> NumberF.median([1, 3, 5, 7, 9])\n    5\n\n    iex> NumberF.median([1, 3, 5, 7])\n    4.0","ref":"NumberF.html#median/1-examples","title":"Examples - NumberF.median/1","type":"function"},{"doc":"Converts a memory size in bytes to a human-readable format.\nAutomatically selects the appropriate unit (B, KB, MB, GB) based on size.","ref":"NumberF.html#memory_size_cal/1","title":"NumberF.memory_size_cal/1","type":"function"},{"doc":"- `size`: The size in bytes","ref":"NumberF.html#memory_size_cal/1-parameters","title":"Parameters - NumberF.memory_size_cal/1","type":"function"},{"doc":"iex> NumberF.memory_size_cal(500)\n    \"500 B\"\n\n    iex> NumberF.memory_size_cal(1024)\n    \"1.0 KB\"\n\n    iex> NumberF.memory_size_cal(1048576)\n    \"1.0 MB\"\n\n    iex> NumberF.memory_size_cal(1073741824)\n    \"1.0 GB\"","ref":"NumberF.html#memory_size_cal/1-examples","title":"Examples - NumberF.memory_size_cal/1","type":"function"},{"doc":"Finds the most frequently occurring value(s) in a list.","ref":"NumberF.html#mode/1","title":"NumberF.mode/1","type":"function"},{"doc":"- `numbers`: A list of numbers","ref":"NumberF.html#mode/1-parameters","title":"Parameters - NumberF.mode/1","type":"function"},{"doc":"iex> NumberF.mode([1, 2, 2, 3, 3, 3, 4])\n    [3]\n\n    iex> NumberF.mode([1, 1, 2, 2, 3])\n    [1, 2]","ref":"NumberF.html#mode/1-examples","title":"Examples - NumberF.mode/1","type":"function"},{"doc":"Formats a number into a delimited format with options for customization.","ref":"NumberF.html#number_to_delimited/2","title":"NumberF.number_to_delimited/2","type":"function"},{"doc":"- `number`: The number to format\n  - `options`: Keyword options for formatting:\n    - `delimiter`: Character used as thousand delimiter (default: \",\")\n    - `separator`: Character used as decimal separator (default: \".\")\n    - `precision`: Number of decimal places (default: 2)","ref":"NumberF.html#number_to_delimited/2-parameters","title":"Parameters - NumberF.number_to_delimited/2","type":"function"},{"doc":"iex> NumberF.number_to_delimited(1234567.89)\n    \"1,234,567.89\"\n\n    iex> NumberF.number_to_delimited(1234567.89, delimiter: \".\", separator: \",\")\n    \"1.234.567,89\"\n\n    iex> NumberF.number_to_delimited(1234567.89, precision: 0)\n    \"1,234,568\"","ref":"NumberF.html#number_to_delimited/2-examples","title":"Examples - NumberF.number_to_delimited/2","type":"function"},{"doc":"Converts numbers to ordinals (1st, 2nd, 3rd, etc.).","ref":"NumberF.html#ordinal/1","title":"NumberF.ordinal/1","type":"function"},{"doc":"- `number`: The number to convert","ref":"NumberF.html#ordinal/1-parameters","title":"Parameters - NumberF.ordinal/1","type":"function"},{"doc":"iex> NumberF.ordinal(1)\n    \"1st\"\n\n    iex> NumberF.ordinal(2)\n    \"2nd\"\n\n    iex> NumberF.ordinal(3)\n    \"3rd\"\n\n    iex> NumberF.ordinal(4)\n    \"4th\"","ref":"NumberF.html#ordinal/1-examples","title":"Examples - NumberF.ordinal/1","type":"function"},{"doc":"Calculates payment due date based on invoice date and terms.","ref":"NumberF.html#payment_due_date/2","title":"NumberF.payment_due_date/2","type":"function"},{"doc":"- `invoice_date`: The invoice date as Date struct\n  - `terms_days`: Payment terms in days (default: 30)","ref":"NumberF.html#payment_due_date/2-parameters","title":"Parameters - NumberF.payment_due_date/2","type":"function"},{"doc":"iex> invoice_date = ~D[2023-01-15]\n    iex> NumberF.payment_due_date(invoice_date)\n    ~D[2023-02-14]\n\n    iex> invoice_date = ~D[2023-01-15]\n    iex> NumberF.payment_due_date(invoice_date, 45)\n    ~D[2023-03-01]","ref":"NumberF.html#payment_due_date/2-examples","title":"Examples - NumberF.payment_due_date/2","type":"function"},{"doc":"Calculates a percentage with specified precision.","ref":"NumberF.html#percentage/3","title":"NumberF.percentage/3","type":"function"},{"doc":"- `value`: The value to calculate percentage for\n  - `total`: The total value (100%)\n  - `precision`: Number of decimal places (default: 2)","ref":"NumberF.html#percentage/3-parameters","title":"Parameters - NumberF.percentage/3","type":"function"},{"doc":"iex> NumberF.percentage(25, 100)\n    25.0\n\n    iex> NumberF.percentage(1, 3, 2)\n    33.33","ref":"NumberF.html#percentage/3-examples","title":"Examples - NumberF.percentage/3","type":"function"},{"doc":"Generates a random string of the specified length.","ref":"NumberF.html#randomizer/2","title":"NumberF.randomizer/2","type":"function"},{"doc":"- `length`: The length of the string\n  - `type`: Type of string, with options:\n    - `:all` (alphanumeric) - default\n    - `:alpha` (alphabetical)\n    - `:numeric` (numbers)\n    - `:upcase` (uppercase)\n    - `:downcase` (lowercase)","ref":"NumberF.html#randomizer/2-parameters","title":"Parameters - NumberF.randomizer/2","type":"function"},{"doc":"iex> NumberF.randomizer(10)\n    \"a1B2c3D4e5\" # Example output, actual value will vary\n\n    iex> NumberF.randomizer(5, :numeric)\n    \"23579\" # Example output, actual value will vary\n\n    iex> NumberF.randomizer(6, :upcase)\n    \"ABCDEF\" # Example output, actual value will vary","ref":"NumberF.html#randomizer/2-examples","title":"Examples - NumberF.randomizer/2","type":"function"},{"doc":"Rounds a number to the nearest specified value.","ref":"NumberF.html#round_to_nearest/2","title":"NumberF.round_to_nearest/2","type":"function"},{"doc":"- `value`: The number to round\n  - `nearest`: The nearest value to round to (default: 1.0)","ref":"NumberF.html#round_to_nearest/2-parameters","title":"Parameters - NumberF.round_to_nearest/2","type":"function"},{"doc":"iex> NumberF.round_to_nearest(12.3)\n    12.0\n\n    iex> NumberF.round_to_nearest(12.3, 5)\n    10.0\n\n    iex> NumberF.round_to_nearest(12.3, 0.5)\n    12.5","ref":"NumberF.html#round_to_nearest/2-examples","title":"Examples - NumberF.round_to_nearest/2","type":"function"},{"doc":"Calculates simple interest based on principal, rate and time.","ref":"NumberF.html#simple_interest/3","title":"NumberF.simple_interest/3","type":"function"},{"doc":"- `principal`: The principal amount\n  - `rate`: The annual interest rate as a decimal (e.g., 0.05 for 5%)\n  - `time`: The time period in years","ref":"NumberF.html#simple_interest/3-parameters","title":"Parameters - NumberF.simple_interest/3","type":"function"},{"doc":"iex> NumberF.simple_interest(1000, 0.05, 2)\n    100.0","ref":"NumberF.html#simple_interest/3-examples","title":"Examples - NumberF.simple_interest/3","type":"function"},{"doc":"Calculates standard deviation of a dataset.","ref":"NumberF.html#standard_deviation/1","title":"NumberF.standard_deviation/1","type":"function"},{"doc":"- `numbers`: A list of numbers","ref":"NumberF.html#standard_deviation/1-parameters","title":"Parameters - NumberF.standard_deviation/1","type":"function"},{"doc":"iex> NumberF.standard_deviation([2, 4, 4, 4, 5, 5, 7, 9])\n    2.0","ref":"NumberF.html#standard_deviation/1-examples","title":"Examples - NumberF.standard_deviation/1","type":"function"},{"doc":"Sums a list of decimal numbers.","ref":"NumberF.html#sum_decimal/1","title":"NumberF.sum_decimal/1","type":"function"},{"doc":"- `list`: A list of decimal values, potentially nested","ref":"NumberF.html#sum_decimal/1-parameters","title":"Parameters - NumberF.sum_decimal/1","type":"function"},{"doc":"iex> sum_decimal([Decimal.new(\"1.2\"), Decimal.new(\"3.4\"), [Decimal.new(\"5.6\")]])\n    #Decimal<10.2>\n\n    iex> sum_decimal([])\n    #Decimal<0>\n\nThis function flattens any nested lists, then uses `Enum.reduce/3` to sum all the decimal values.","ref":"NumberF.html#sum_decimal/1-examples","title":"Examples - NumberF.sum_decimal/1","type":"function"},{"doc":"Converts a string to a boolean value.","ref":"NumberF.html#to_boolean/1","title":"NumberF.to_boolean/1","type":"function"},{"doc":"- `value`: The string value to convert. Accepts the following:\n    - `true`, `yes`, `on` convert to `true`\n    - `false`, `no`, `off` convert to `false`\n    - Any other value raises an ArgumentError","ref":"NumberF.html#to_boolean/1-parameters","title":"Parameters - NumberF.to_boolean/1","type":"function"},{"doc":"iex> NumberF.to_boolean(\"true\")\n    true\n\n    iex> NumberF.to_boolean(\"yes\")\n    true\n\n    iex> NumberF.to_boolean(\"false\")\n    false\n\n    iex> NumberF.to_boolean(\"no\")\n    false","ref":"NumberF.html#to_boolean/1-examples","title":"Examples - NumberF.to_boolean/1","type":"function"},{"doc":"Converts a value to a decimal.","ref":"NumberF.html#to_decimal/1","title":"NumberF.to_decimal/1","type":"function"},{"doc":"- `value`: The value to convert (string or number)","ref":"NumberF.html#to_decimal/1-parameters","title":"Parameters - NumberF.to_decimal/1","type":"function"},{"doc":"iex> NumberF.to_decimal(\"123.45\")\n    #Decimal<123.45>\n\n    iex> NumberF.to_decimal(123)\n    #Decimal<123>","ref":"NumberF.html#to_decimal/1-examples","title":"Examples - NumberF.to_decimal/1","type":"function"},{"doc":"Converts a value to a float.","ref":"NumberF.html#to_float/1","title":"NumberF.to_float/1","type":"function"},{"doc":"- `value`: The value to convert (string or number)","ref":"NumberF.html#to_float/1-parameters","title":"Parameters - NumberF.to_float/1","type":"function"},{"doc":"iex> NumberF.to_float(\"123.45\")\n    123.45\n\n    iex> NumberF.to_float(123)\n    123.0","ref":"NumberF.html#to_float/1-examples","title":"Examples - NumberF.to_float/1","type":"function"},{"doc":"Converts a string to an integer.","ref":"NumberF.html#to_int/1","title":"NumberF.to_int/1","type":"function"},{"doc":"- `value`: The string value to convert","ref":"NumberF.html#to_int/1-parameters","title":"Parameters - NumberF.to_int/1","type":"function"},{"doc":"iex> NumberF.to_int(\"123\")\n    123\n\n    iex> NumberF.to_int(\"123.45\")\n    123","ref":"NumberF.html#to_int/1-examples","title":"Examples - NumberF.to_int/1","type":"function"},{"doc":"Converts Arabic numbers to Roman numerals.","ref":"NumberF.html#to_roman/1","title":"NumberF.to_roman/1","type":"function"},{"doc":"- `number`: The number to convert (1-3999)","ref":"NumberF.html#to_roman/1-parameters","title":"Parameters - NumberF.to_roman/1","type":"function"},{"doc":"iex> NumberF.to_roman(4)\n    \"IV\"\n\n    iex> NumberF.to_roman(42)\n    \"XLII\"\n\n    iex> NumberF.to_roman(1999)\n    \"MCMXCIX\"","ref":"NumberF.html#to_roman/1-examples","title":"Examples - NumberF.to_roman/1","type":"function"},{"doc":"Converts a number into words with customizable currency terms.","ref":"NumberF.html#to_words/3","title":"NumberF.to_words/3","type":"function"},{"doc":"- `amount`: The number to convert\n  - `main_currency`: The main currency name (default: \"Kwacha\")\n  - `sec_currency`: The secondary currency name (default: \"Ngwee\")","ref":"NumberF.html#to_words/3-parameters","title":"Parameters - NumberF.to_words/3","type":"function"},{"doc":"iex> NumberF.to_words(20.0)\n    \"Twenty Kwacha and zero Ngwee\"\n\n    iex> NumberF.to_words(42.75, \"Dollars\", \"Cents\")\n    \"Forty Two Dollars And Seventy Five Cents\"\n\n    iex> NumberF.to_words(0, \"Euros\", \"Cents\")\n    \"zero Euros\"","ref":"NumberF.html#to_words/3-examples","title":"Examples - NumberF.to_words/3","type":"function"},{"doc":"General numeric calculation functions.","ref":"NumberF.Calculations.html","title":"NumberF.Calculations","type":"module"},{"doc":"Calculates combinations (n choose k).","ref":"NumberF.Calculations.html#combinations/2","title":"NumberF.Calculations.combinations/2","type":"function"},{"doc":"Calculates factorial of a non-negative integer.","ref":"NumberF.Calculations.html#factorial/1","title":"NumberF.Calculations.factorial/1","type":"function"},{"doc":"Calculates the Greatest Common Divisor (GCD) of two integers.","ref":"NumberF.Calculations.html#gcd/2","title":"NumberF.Calculations.gcd/2","type":"function"},{"doc":"Checks if a number is within a specified range (inclusive).","ref":"NumberF.Calculations.html#in_range?/3","title":"NumberF.Calculations.in_range?/3","type":"function"},{"doc":"Performs a linear interpolation between two points.","ref":"NumberF.Calculations.html#interpolate/5","title":"NumberF.Calculations.interpolate/5","type":"function"},{"doc":"Checks if a number is prime.","ref":"NumberF.Calculations.html#is_prime?/1","title":"NumberF.Calculations.is_prime?/1","type":"function"},{"doc":"Calculates the Least Common Multiple (LCM) of two integers.","ref":"NumberF.Calculations.html#lcm/2","title":"NumberF.Calculations.lcm/2","type":"function"},{"doc":"Calculates a percentage with specified precision.","ref":"NumberF.Calculations.html#percentage/3","title":"NumberF.Calculations.percentage/3","type":"function"},{"doc":"Rounds a number to the nearest specified value.","ref":"NumberF.Calculations.html#round_to_nearest/2","title":"NumberF.Calculations.round_to_nearest/2","type":"function"},{"doc":"Converts radians to degrees.","ref":"NumberF.Calculations.html#to_degrees/1","title":"NumberF.Calculations.to_degrees/1","type":"function"},{"doc":"Converts degrees to radians.","ref":"NumberF.Calculations.html#to_radians/1","title":"NumberF.Calculations.to_radians/1","type":"function"},{"doc":"Functions for financial calculations such as interest, EMI, and currency conversion.","ref":"NumberF.Financial.html","title":"NumberF.Financial","type":"module"},{"doc":"Calculates EMI (Equated Monthly Installment).","ref":"NumberF.Financial.html#calculate_emi/3","title":"NumberF.Financial.calculate_emi/3","type":"function"},{"doc":"Calculates compound interest.","ref":"NumberF.Financial.html#compound_interest/4","title":"NumberF.Financial.compound_interest/4","type":"function"},{"doc":"Converts currency based on exchange rates.","ref":"NumberF.Financial.html#convert_currency/3","title":"NumberF.Financial.convert_currency/3","type":"function"},{"doc":"Calculates simple interest.","ref":"NumberF.Financial.html#simple_interest/3","title":"NumberF.Financial.simple_interest/3","type":"function"},{"doc":"Functions for statistical calculations and analysis of numerical data.","ref":"NumberF.Statistics.html","title":"NumberF.Statistics","type":"module"},{"doc":"Calculates the arithmetic mean of a list of numbers.","ref":"NumberF.Statistics.html#mean/1","title":"NumberF.Statistics.mean/1","type":"function"},{"doc":"Finds the median value from a list of numbers.","ref":"NumberF.Statistics.html#median/1","title":"NumberF.Statistics.median/1","type":"function"},{"doc":"Finds the most frequently occurring value(s) in a list.","ref":"NumberF.Statistics.html#mode/1","title":"NumberF.Statistics.mode/1","type":"function"},{"doc":"Calculates the range (difference between max and min values).","ref":"NumberF.Statistics.html#range/1","title":"NumberF.Statistics.range/1","type":"function"},{"doc":"Calculates standard deviation of a dataset.","ref":"NumberF.Statistics.html#standard_deviation/1","title":"NumberF.Statistics.standard_deviation/1","type":"function"},{"doc":"Calculates the variance of a dataset.","ref":"NumberF.Statistics.html#variance/1","title":"NumberF.Statistics.variance/1","type":"function"},{"doc":"Functions for formatting numbers and related data in various formats.","ref":"NumberF.Formatter.html","title":"NumberF.Formatter","type":"module"},{"doc":"Formats large numbers as K, M, B (e.g., 1.2K, 3.4M).","ref":"NumberF.Formatter.html#abbreviate_number/2","title":"NumberF.Formatter.abbreviate_number/2","type":"function"},{"doc":"Formats phone numbers based on country code.","ref":"NumberF.Formatter.html#format_phone/2","title":"NumberF.Formatter.format_phone/2","type":"function"},{"doc":"Converts Roman numerals to Arabic numbers.","ref":"NumberF.Formatter.html#from_roman/1","title":"NumberF.Formatter.from_roman/1","type":"function"},{"doc":"Converts numbers to ordinals (1st, 2nd, 3rd, etc.).","ref":"NumberF.Formatter.html#ordinal/1","title":"NumberF.Formatter.ordinal/1","type":"function"},{"doc":"Converts Arabic numbers to Roman numerals.","ref":"NumberF.Formatter.html#to_roman/1","title":"NumberF.Formatter.to_roman/1","type":"function"},{"doc":"Functions for validating various numeric formats and related data.","ref":"NumberF.Validation.html","title":"NumberF.Validation","type":"module"},{"doc":"Validates credit card numbers using the Luhn algorithm.","ref":"NumberF.Validation.html#is_valid_credit_card?/2","title":"NumberF.Validation.is_valid_credit_card?/2","type":"function"},{"doc":"Checks if a string is a valid integer.","ref":"NumberF.Validation.html#is_valid_integer?/1","title":"NumberF.Validation.is_valid_integer?/1","type":"function"},{"doc":"Checks if a string is a valid number format.","ref":"NumberF.Validation.html#is_valid_number?/1","title":"NumberF.Validation.is_valid_number?/1","type":"function"},{"doc":"","ref":"NumberF.NumberToWord.html","title":"NumberF.NumberToWord","type":"module"},{"doc":"","ref":"NumberF.NumberToWord.html#format/4","title":"NumberF.NumberToWord.format/4","type":"function"},{"doc":"","ref":"NumberF.NumberToWord.html#say/1","title":"NumberF.NumberToWord.say/1","type":"function"},{"doc":"","ref":"NumberF.NumberToWord.html#say_io/1","title":"NumberF.NumberToWord.say_io/1","type":"function"},{"doc":"","ref":"NumberF.NumberToWord.html#separator/1","title":"NumberF.NumberToWord.separator/1","type":"function"},{"doc":"","ref":"NumberF.NumbersToWords.html","title":"NumberF.NumbersToWords","type":"module"},{"doc":"","ref":"NumberF.NumbersToWords.html#parse/3","title":"NumberF.NumbersToWords.parse/3","type":"function"},{"doc":"","ref":"NumberF.NumbersToWords.html#try/0","title":"NumberF.NumbersToWords.try/0","type":"function"},{"doc":"Functions for performing date-based calculations.","ref":"NumberF.DateCalculations.html","title":"NumberF.DateCalculations","type":"module"},{"doc":"Calculates the date after adding a specified number of business days.","ref":"NumberF.DateCalculations.html#add_business_days/2","title":"NumberF.DateCalculations.add_business_days/2","type":"function"},{"doc":"Calculates the number of business days between two dates.","ref":"NumberF.DateCalculations.html#business_days_between/2","title":"NumberF.DateCalculations.business_days_between/2","type":"function"},{"doc":"Calculates age based on birth date.","ref":"NumberF.DateCalculations.html#calculate_age/1","title":"NumberF.DateCalculations.calculate_age/1","type":"function"},{"doc":"Calculates the number of days between two dates.","ref":"NumberF.DateCalculations.html#days_between/2","title":"NumberF.DateCalculations.days_between/2","type":"function"},{"doc":"Determines if a date is a business day.","ref":"NumberF.DateCalculations.html#is_business_day?/1","title":"NumberF.DateCalculations.is_business_day?/1","type":"function"},{"doc":"Calculates the next business day after the given date.","ref":"NumberF.DateCalculations.html#next_business_day/1","title":"NumberF.DateCalculations.next_business_day/1","type":"function"},{"doc":"Calculates payment due date based on invoice date and terms.","ref":"NumberF.DateCalculations.html#payment_due_date/2","title":"NumberF.DateCalculations.payment_due_date/2","type":"function"},{"doc":"# NumberF\n\n**TODO: Add description**","ref":"readme.html","title":"NumberF","type":"extras"},{"doc":"If [available in Hex](https://hex.pm/docs/publish), the package can be installed\nby adding `number_f` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:number_f, \"~> 0.1.3\"}\n  ]\nend\n```\n\nDocumentation can be generated with [ExDoc](https://github.com/elixir-lang/ex_doc)\nand published on [HexDocs](https://hexdocs.pm). Once published, the docs can\nbe found at  .","ref":"readme.html#installation","title":"Installation - NumberF","type":"extras"},{"doc":"MIT License\n\nJam@6756\n\nCopyright (c) 2024 James Njovu.\n\nPermission is hereby granted, free of charge, to any person obtaining a copy\nof this software and associated documentation files (the \"Software\"), to deal\nin the Software without restriction, including without limitation the rights\nto use, copy, modify, merge, publish, distribute, sublicense, and/or sell\ncopies of the Software, and to permit persons to whom the Software is\nfurnished to do so, subject to the following conditions:\n\nThe above copyright notice and this permission notice shall be included in all\ncopies or substantial portions of the Software.\n\nTHE SOFTWARE IS PROVIDED \"AS IS\", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR\nIMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,\nFITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE\nAUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER\nLIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,\nOUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE\nSOFTWARE.","ref":"license.html","title":"LICENSE","type":"extras"}],"producer":{"name":"ex_doc","version":"0.37.3"},"proglang":"elixir"}